==> qtjambi-quick-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiQuick/QSGGeometry_AttributeSet_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_AttributeSet(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::AttributeSet")
    QSGGeometry::AttributeSet *_ptr = reinterpret_cast<QSGGeometry::AttributeSet *>(ptr);
    if(!isShell){
        delete[] _ptr->attributes;
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new AttributeSet()
void __qt_construct_QSGGeometry_AttributeSet(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct AttributeSet()")
    Q_UNUSED(__java_arguments)
    QSGGeometry::AttributeSet *__qt_this = new(__qtjambi_ptr) QSGGeometry::AttributeSet();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QSGGeometry::AttributeSet::AttributeSet()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_initialize_1native__Lio_qt_quick_QSGGeometry_00024AttributeSet_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::AttributeSet::AttributeSet()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_AttributeSet, sizeof(QSGGeometry::AttributeSet), typeid(QSGGeometry::AttributeSet), false, &deleter_QSGGeometry_AttributeSet, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new AttributeSet(QSGGeometry::AttributeSet)
void __qt_construct_QSGGeometry_AttributeSet_cref_QSGGeometry_AttributeSet(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct AttributeSet(QSGGeometry::AttributeSet)")
    jobject other0 = __java_arguments[0].l;
    const QSGGeometry::AttributeSet& __qt_other0 = qtjambi_cast<const QSGGeometry::AttributeSet& >(__jni_env, other0);
    QSGGeometry::AttributeSet *__qt_this = new(__qtjambi_ptr) QSGGeometry::AttributeSet(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)


    QSGGeometry::Attribute* attributes;
    __qt_this->attributes = attributes = __qt_other0.count>0 ? new QSGGeometry::Attribute[__qt_other0.count] : nullptr;
    for(int i=0; i<__qt_other0.count; ++i){
        attributes[i] = __qt_other0.attributes[i];
    }
    Q_UNUSED(__jni_object)
}

// QSGGeometry::AttributeSet::AttributeSet(QSGGeometry::AttributeSet)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_initialize_1native__Lio_qt_quick_QSGGeometry_00024AttributeSet_2Lio_qt_quick_QSGGeometry_00024AttributeSet_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::AttributeSet::AttributeSet(QSGGeometry::AttributeSet)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_AttributeSet_cref_QSGGeometry_AttributeSet, sizeof(QSGGeometry::AttributeSet), typeid(QSGGeometry::AttributeSet), false, &deleter_QSGGeometry_AttributeSet, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new AttributeSet{int,int,const QSGGeometry::Attribute*}
void __qt_construct_QSGGeometry_AttributeSet_int_int_const_QSGGeometry_Attribute_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct AttributeSet{int,int,const QSGGeometry::Attribute*}")
    jint stride1 = __java_arguments[0].i;
    Q_UNUSED(stride1)
    jobjectArray attributes2 = static_cast<jobjectArray>(__java_arguments[1].l);
    jsize count0 = attributes2 ? __jni_env->GetArrayLength(attributes2) : 0;
    QSGGeometry::Attribute* __qt_attributes2 = count0>0 ? new QSGGeometry::Attribute[count0] : nullptr;
    for(jsize i=0; i<count0; ++i){
        jobject element = __jni_env->GetObjectArrayElement(attributes2, i);
        JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO);
        __qt_attributes2[i] = qtjambi_cast<const QSGGeometry::Attribute&>(__jni_env, element);
    }
    QSGGeometry::AttributeSet *__qt_this = new(__qtjambi_ptr) QSGGeometry::AttributeSet{static_cast<int>(count0), static_cast<int>(stride1), __qt_attributes2};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QSGGeometry::AttributeSet::AttributeSet{int,int,const QSGGeometry::Attribute*}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_initialize_1native__Lio_qt_quick_QSGGeometry_00024AttributeSet_2I_3Lio_qt_quick_QSGGeometry_00024Attribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint stride1,
 jobjectArray attributes2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::AttributeSet::AttributeSet{int,int,const QSGGeometry::Attribute*}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].i = stride1;
        arguments[1].l = attributes2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_AttributeSet_int_int_const_QSGGeometry_Attribute_ptr, sizeof(QSGGeometry::AttributeSet), typeid(QSGGeometry::AttributeSet), false, &deleter_QSGGeometry_AttributeSet, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGGeometry::AttributeSet
void __qt_destruct_QSGGeometry_AttributeSet(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::AttributeSet")
    reinterpret_cast<QSGGeometry::AttributeSet*>(ptr)->~AttributeSet();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_equals_1native_1cref_1QSGGeometry_1AttributeSet__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)", __qt_this)
        const QSGGeometry::AttributeSet& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QSGGeometry::AttributeSet>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_setAttributes_1native_1const_1QSGGeometry_1Attribute_1ptr__J_3Lio_qt_quick_QSGGeometry_00024Attribute_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobjectArray attributes0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->count = attributes0 ? __jni_env->GetArrayLength(jobjectArray(attributes0)) : 0;
        QSGGeometry::Attribute* __qt_attributes0 = __qt_this->count>0 ? new QSGGeometry::Attribute[__qt_this->count] : nullptr;
        for(jsize i=0; i<jsize(__qt_this->count); ++i){
            jobject element = __jni_env->GetObjectArrayElement(jobjectArray(attributes0), i);
            JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO);
            __qt_attributes0[i] = qtjambi_cast<const QSGGeometry::Attribute&>(__jni_env, element);
        }
        __qt_this->attributes = __qt_attributes0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobjectArray JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_attributes_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    jobjectArray __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QSGGeometry::Attribute*  __qt_value = __qt_this->attributes;
        __java_return_value = qtjambi_array_cast<jobjectArray>(__jni_env, __qtjambi_scope, __qt_value, __qt_this->count);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_count_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->count;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_setStride_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint stride0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->stride = static_cast<int>(stride0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_stride_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->stride;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCustomStructors)
void* custom_constructor_QSGGeometry_AttributeSet(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QSGGeometry::AttributeSet* copy = static_cast<const QSGGeometry::AttributeSet*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        QSGGeometry::AttributeSet* result = new(placement) QSGGeometry::AttributeSet{*copy};
        QSGGeometry::Attribute* attributes;
        result->attributes = attributes = copy->count>0 ? new QSGGeometry::Attribute[copy->count] : nullptr;
        for(int i=0; i<copy->count; ++i){
            attributes[i] = copy->attributes[i];
        }
        return result;
    }else{
        return new(placement) QSGGeometry::AttributeSet{};
    }
}
void custom_destructor_QSGGeometry_AttributeSet(
                                                   void * __in_var)
{
    QSGGeometry::AttributeSet* ptr = static_cast<QSGGeometry::AttributeSet*>(__in_var);
    Q_UNUSED(ptr)
    delete[] ptr->attributes;
    ptr->count = 0;
    ptr->stride = 0;
    ptr->attributes = nullptr;
    ptr->~AttributeSet();
    
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_AttributeSet(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet", "io/qt/quick/QSGGeometry$AttributeSet");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_AttributeSet, {
        ConstructorInfo(&__qt_construct_QSGGeometry_AttributeSet, nullptr)
       ,ConstructorInfo(&__qt_construct_QSGGeometry_AttributeSet_cref_QSGGeometry_AttributeSet, "Lio/qt/quick/QSGGeometry$AttributeSet;")
       ,ConstructorInfo(&__qt_construct_QSGGeometry_AttributeSet_int_int_const_QSGGeometry_Attribute_ptr, "I[Lio/qt/quick/QSGGeometry$Attribute;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_AttributeSet);
    registerMetaType<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet", &custom_destructor_QSGGeometry_AttributeSet, &custom_constructor_QSGGeometry_AttributeSet);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiQuick/QSGGeometry_AttributeSet_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_AttributeSet(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::AttributeSet")
    QSGGeometry::AttributeSet *_ptr = reinterpret_cast<QSGGeometry::AttributeSet *>(ptr);
    if(!isShell){
        delete[] _ptr->attributes;
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSGGeometry_AttributeSet_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    jobjectArray attributes = static_cast<jobjectArray>(__java_arguments[0].l);
    jint stride = __java_arguments[1].i;
    QSGGeometry::AttributeSet *__qt_this = new(__qtjambi_ptr) QSGGeometry::AttributeSet();


    __qt_this->stride = stride;
    __qt_this->count = __jni_env->GetArrayLength(attributes);
    QSGGeometry::Attribute* _attributes = new QSGGeometry::Attribute[size_t(__qt_this->count)];
    __qt_this->attributes = _attributes;
    for(jsize i=0; i<jsize(__qt_this->count); ++i){
        jobject element = __jni_env->GetObjectArrayElement(attributes, i);
        _attributes[i] = qtjambi_cast<const QSGGeometry::Attribute&>(__jni_env, element);
    }
    Q_UNUSED(__jni_object)
}

// destruct QSGGeometry::AttributeSet
void __qt_destruct_QSGGeometry_AttributeSet(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::AttributeSet")
    reinterpret_cast<QSGGeometry::AttributeSet*>(ptr)->~AttributeSet();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::AttributeSet::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_initialize_1native__Lio_qt_quick_QSGGeometry_00024AttributeSet_2_3Lio_qt_quick_QSGGeometry_00024Attribute_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobjectArray attributes,
 jint stride)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::AttributeSet::")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = attributes;
        arguments[0].i = stride;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_AttributeSet_0, sizeof(QSGGeometry::AttributeSet), typeid(QSGGeometry::AttributeSet), false, &deleter_QSGGeometry_AttributeSet, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_equals_1native_1cref_1QSGGeometry_1AttributeSet__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)", __qt_this)
        const QSGGeometry::AttributeSet& __qt_value21 = QtJambiAPI::objectReferenceFromNativeId<QSGGeometry::AttributeSet>(__jni_env, value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jobjectArray JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_attributes_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    jobjectArray __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QSGGeometry::Attribute*  __qt_value = __qt_this->attributes;
        __java_return_value = qtjambi_array_cast<jobjectArray>(__jni_env, __qtjambi_scope, __qt_value, __qt_this->count);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_count_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->count;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_stride_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->stride;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_AttributeSet(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet", "io/qt/quick/QSGGeometry$AttributeSet");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_AttributeSet, {
        ConstructorInfo(&__qt_construct_QSGGeometry_AttributeSet_0, "[Lio/qt/quick/QSGGeometry$Attribute;I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_AttributeSet);
    registerMetaType<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
